@@ -13,16 +13,20 @@ except ImportError:  # Fails on vendored-in LSP plugin
 
     RICH_PRESENT = False
 
-from robotidy import app, decorators, exceptions, files, skip, utils, version
+from robotidy import app, decorators, files, skip, utils, version
 from robotidy.config import Config, FormattingConfig
 from robotidy.rich_console import console
-from robotidy.transformers import TransformType, load_transformers
+from robotidy.transformers import TransformConfig, TransformConfigMap, TransformConfigParameter, load_transformers
 
 CLI_OPTIONS_LIST = [
     {
         "name": "Run only selected transformers",
         "options": ["--transform"],
     },
+    {
+        "name": "Load custom transformers",
+        "options": ["--load-transformers"],
+    },
     {
         "name": "Work modes",
         "options": ["--overwrite", "--diff", "--check", "--force-order"],
@@ -165,7 +169,8 @@ def print_transformer_docs(transformer):
 
 @decorators.optional_rich
 def print_description(name: str, target_version: int):
-    transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
+    # TODO: --desc works only for default transformers, it should also print custom transformer desc
+    transformers = load_transformers(TransformConfigMap([], [], []), allow_disabled=True, target_version=target_version)
     transformer_by_names = {transformer.name: transformer for transformer in transformers}
     if name == "all":
         for transformer in transformers:
@@ -180,18 +185,10 @@ def print_description(name: str, target_version: int):
     return 0
 
 
-def _load_external_transformers(
-    transformers: List,
-    transformers_from_config: List[Tuple[str, List]],
-    transformer_config: List[Tuple[str, List]],
-    target_version: int,
-):
+def _load_external_transformers(transformers: List, transformers_config: TransformConfigMap, target_version: int):
     external = []
     transformers_names = {transformer.name for transformer in transformers}
-    transformer_config_converted = Config.convert_configure(transformer_config)
-    transformers_from_conf = load_transformers(
-        transformers_from_config, transformer_config_converted, target_version=target_version
-    )
+    transformers_from_conf = load_transformers(transformers_config, target_version=target_version)
     for transformer in transformers_from_conf:
         if transformer.name not in transformers_names:
             external.append(transformer)
@@ -200,21 +197,15 @@ def _load_external_transformers(
 
 @decorators.optional_rich
 def print_transformers_list(
-    transformers_from_config: List[Tuple[str, List]],
-    transformer_config: List[Tuple[str, List]],
-    config: Config,
-    target_version: int,
-    list_transformers: str,
+    transformers_config: TransformConfigMap, config: Config, target_version: int, list_transformers: str
 ):
     from rich.table import Table
 
     table = Table(title="Transformers", header_style="bold red")
     table.add_column("Name", justify="left", no_wrap=True)
     table.add_column("Enabled")
-    transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
-    transformers.extend(
-        _load_external_transformers(transformers, transformers_from_config, transformer_config, target_version)
-    )
+    transformers = load_transformers(TransformConfigMap([], [], []), allow_disabled=True, target_version=target_version)
+    transformers.extend(_load_external_transformers(transformers, transformers_config, target_version))
 
     for transformer in transformers:
         enabled = transformer.name in config.transformers_lookup
@@ -245,15 +236,23 @@ def print_transformers_list(
 @click.option(
     "--transform",
     "-t",
-    type=TransformType(),
+    type=TransformConfigParameter(),
     multiple=True,
     metavar="TRANSFORMER_NAME",
-    help="Transform files from \[PATH(S)] with given transformer",
+    help="Transform files from [PATH(S)] with given transformer",
+)
+@click.option(
+    "--load-transformers",
+    "custom_transformers",
+    type=TransformConfigParameter(),
+    multiple=True,
+    metavar="TRANSFORMER_NAME",
+    help="Load custom transformer from the path and run them after default ones.",
 )
 @click.option(
     "--configure",
     "-c",
-    type=TransformType(),
+    type=TransformConfigParameter(),
     multiple=True,
     metavar="TRANSFORMER_NAME:PARAM=VALUE",
     help="Configure transformers",
@@ -305,6 +304,13 @@ def print_transformers_list(
     callback=read_config,
     help="Read configuration from FILE path.",
 )
+# This option is workaround to make it possible to pass configuration directory when reading config.
+# We first load the config file and then map every value from it as cli option defaults. The option must exist, so we
+# cannot pass additional info, ie the directory where config file was found.
+@click.option(
+    "--config-directory",
+    hidden=True,
+)
 @click.option(
     "--overwrite/--no-overwrite",
     default=None,
@@ -447,6 +453,13 @@ def print_transformers_list(
     help="Parse Robot Framework files using additional languages.",
     show_default="en",
 )
+@click.option(
+    "--reruns",
+    "-r",
+    type=int,
+    help="Robotidy will rerun the transformations up to reruns times until the code stop changing.",
+    show_default="0",
+)
 @skip.comments_option
 @skip.documentation_option
 @skip.return_values_option
@@ -460,14 +473,16 @@ def print_transformers_list(
 @skip.template_option
 @skip.return_option
 @skip.tags_option
+@skip.sections_option
 @skip.block_comments_option
 @click.version_option(version=version.__version__, prog_name="robotidy")
 @click.pass_context
 @decorators.catch_exceptions
 def cli(
     ctx: click.Context,
-    transform: List[Tuple[str, List]],
-    configure: List[Tuple[str, List]],
+    transform: List[TransformConfig],
+    custom_transformers: List[TransformConfig],
+    configure: List[TransformConfig],
     src: Tuple[str, ...],
     exclude: Optional[Pattern],
     extend_exclude: Optional[Pattern],
@@ -482,6 +497,7 @@ def cli(
     lineseparator: str,
     verbose: bool,
     config: Optional[str],
+    config_directory: Optional[str],
     separator: Optional[str],
     startline: Optional[int],
     endline: Optional[int],
@@ -492,6 +508,7 @@ def cli(
     force_order: bool,
     target_version: int,
     language: Optional[List[str]],
+    reruns: int,
     skip_comments: bool,
     skip_documentation: bool,
     skip_return_values: bool,
@@ -506,6 +523,7 @@ def cli(
     skip_return: bool,
     skip_tags: bool,
     skip_block_comments: bool,
+    skip_sections: str,
 ):
     """
     Robotidy is a tool for formatting Robot Framework source code.
@@ -546,6 +564,7 @@ def cli(
         tags=skip_tags,
         comments=skip_comments,
         block_comments=skip_block_comments,
+        sections=skip_sections,
     )
 
     formatting = FormattingConfig(
@@ -558,11 +577,12 @@ def cli(
         end_line=endline,
         line_length=line_length,
     )
+
+    transformers_config = TransformConfigMap(transform, custom_transformers, configure)
     config = Config(
         formatting=formatting,
         skip=skip_config,
-        transformers=transform,
-        transformers_config=configure,
+        transformers_config=transformers_config,
         src=src,
         exclude=exclude,
         extend_exclude=extend_exclude,
@@ -576,10 +596,12 @@ def cli(
         target_version=target_version,
         color=color,
         language=language,
+        reruns=reruns,
+        config_directory=config_directory,
     )
 
     if list_transformers:
-        print_transformers_list(transform, configure, config, target_version, list_transformers)
+        print_transformers_list(transformers_config, config, target_version, list_transformers)
         sys.exit(0)
     if desc is not None:
         return_code = print_description(desc, target_version)
